<div align="center">
    <a href="https://github.com/demergent-labs/kybra" target="_blank" rel="noopener noreferrer">
        <img height="150" src="https://raw.githubusercontent.com/demergent-labs/kybra/main/logo/logo.svg" alt="kybra logo">
    </a>
</div>
</br>
<div align="center">
    <a href="https://github.com/demergent-labs/kybra/actions/workflows/test.yml?query=branch%3Amain">
        <img src="https://github.com/demergent-labs/kybra/actions/workflows/test.yml/badge.svg" alt="Coverage Status">
    </a>
    <a href="https://badge.fury.io/py/kybra"><img src="https://badge.fury.io/py/kybra.svg" alt="PyPI version"></a>
</div>

# Kybra (Beta)

Python CDK for the [Internet Computer](https://internetcomputer.org/).

## Disclaimer

Kybra may have unknown security vulnerabilities due to the following:

-   Kybra does not yet have many live, successful, continuously operating applications deployed to the IC
-   Kybra does not yet have extensive automated property tests
-   Kybra does not yet have multiple independent security reviews/audits
-   Kybra uses a new Python interpreter that is less mature than CPython

## Roadmap

We hope to get to a production-ready 1.0 in 2024. The following are the major blockers to 1.0:

-   CPython integration for performance, security, and stability
-   Broad PyPI package support (C API/extensions)
-   Extensive automated property testing
-   Multiple independent security reviews/audits

## Documentation

See [The Kybra Book](https://demergent-labs.github.io/kybra/).

## Discussion

Feel free to open issues or join us in the [Discord channel](https://discord.gg/ux2Jc7psjd).

## Contributing

Not currently taking contributions, but definitely taking issues and questions. Please allow time for initial code architecture and governance/legal/token work to be put in place. Kybra will most likely have a license extension [similar to Azle's](https://github.com/demergent-labs/azle/blob/main/LICENSE_EXTENSION.md).
